bt Package
==========

:mod:`bt` Package
-----------------

.. automodule:: bt.__init__
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`algos` Module
-------------------

.. automodule:: bt.algos
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`backtest` Module
----------------------

.. automodule:: bt.backtest
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`core` Module
------------------

.. automodule:: bt.core
    :members:
    :undoc-members:
    :show-inheritance:

